/resources/audience.proto

--- v14/resources/audience.proto    2023-10-18 04:25:31.000000000 +0000
+++ v15/resources/audience.proto    2023-10-18 04:25:35.000000000 +0000
@@ -58,13 +59,14 @@

   // Output only. Status of this audience. Indicates whether the audience
   // is enabled or removed.
-  google.ads.googleads.v14.enums.AudienceStatusEnum.AudienceStatus status = 3
+  google.ads.googleads.v15.enums.AudienceStatusEnum.AudienceStatus status = 3
       [(google.api.field_behavior) = OUTPUT_ONLY];

-  // Required. Name of the audience. It should be unique across all
-  // audiences. It must have a minimum length of 1 and
-  // maximum length of 255.
-  string name = 4 [(google.api.field_behavior) = REQUIRED];
+  // Name of the audience. It should be unique across all audiences within the
+  // account. It must have a minimum length of 1 and maximum length of 255.
+  // Required when scope is not set or is set to CUSTOMER. Cannot be set or
+  // updated when scope is ASSET_GROUP.
+  optional string name = 10;

   // Description of this audience.
   string description = 5;
@@ -70,9 +72,26 @@
   string description = 5;

   // Positive dimensions specifying the audience composition.
-  repeated google.ads.googleads.v14.common.AudienceDimension dimensions = 6;
+  repeated google.ads.googleads.v15.common.AudienceDimension dimensions = 6;

   // Negative dimension specifying the audience composition.
-  google.ads.googleads.v14.common.AudienceExclusionDimension
+  google.ads.googleads.v15.common.AudienceExclusionDimension
       exclusion_dimension = 7;
+
+  // Defines the scope this audience can be used in. By default, the scope is
+  // CUSTOMER. Audiences can be created with a scope of ASSET_GROUP for
+  // exclusive use by a single asset_group. Scope may change from ASSET_GROUP to
+  // CUSTOMER but not from CUSTOMER to ASSET_GROUP.
+  google.ads.googleads.v15.enums.AudienceScopeEnum.AudienceScope scope = 8;
+
+  // Immutable. The asset group that this audience is scoped under. Must be set
+  // if and only if scope is ASSET_GROUP. Immutable after creation. If an
+  // audience with ASSET_GROUP scope is upgraded to CUSTOMER scope, this field
+  // will automatically be cleared.
+  string asset_group = 9 [
+    (google.api.field_behavior) = IMMUTABLE,
+    (google.api.resource_reference) = {
+      type: "googleads.googleapis.com/AssetGroup"
+    }
+  ];
 }